<?php

namespace Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Method;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Exception;

class Cmp00600ParametrosComprasSuprimentosController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceManager;
    protected $crudService;
	protected $dataSourceNameToSave;
	protected $connection;
	protected $supUtilities;
    protected $cdgrupoper;
    protected $cdfilial;
    protected $tipo;
    protected $newCode;

    public function __construct($crudService,  $environment, $dataSourceManager, $connection, $newCode, $supUtilities) {
        $this->crudService       = $crudService;
        $this->environment       = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection        = $connection;
        $this->newCode           = $newCode;
        $this->supUtilities      = $supUtilities;
    }

    public function saveFilial (DTO\Request\Row $request, DTO\Response $response){
    	$this->saveFilialData($request, $response);
    }

    public function saveGrupoOperador(DTO\Request\DataSet $request, DTO\Response $response){
    	$this->saveGrupoOper($request, $response);
    }

    public function saveFilialData ($request, $response){
        
    	try {
            $this->dataSourceNameToSave = 'parasupri';
            parent::save($request,$response);
            
            //método separado para atualizar o campo IDUTLSUBGRPRODFIL
            $row = $request->getRow();
            $this->updateIDUTLSUBGRPRODFIL($row['IDUTLSUBGRPRODFIL'],$row['CDFILIAL']);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function updateIDUTLSUBGRPRODFIL($P_IDUTLSUBGRPRODFIL, $P_CDFILIAL)
    {
        $sql = "UPDATE PARASUPRI 
                   SET IDUTLSUBGRPRODFIL = :P_IDUTLSUBGRPRODFIL 
                 WHERE CDFILIAL = :P_CDFILIAL 
                   AND NRORG    = :P_NRORG";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'P_IDUTLSUBGRPRODFIL'  => $P_IDUTLSUBGRPRODFIL,
                'P_CDFILIAL' => $P_CDFILIAL,
                'P_NRORG'       => $this->environment->getNrorg()
            )
        );
    }
    
    public function saveGrupoOper($request, $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();
            $perfiAcesso = false;
            
            foreach($rows as $row) {
                if($row['GRUPOPER']) {
                    $this->deleteAutGrupOp($row);
                    $this->insertAutGrupOp($row);
                } else {
                    if($row['NRAUTPERFACESSO']){
                        $this->deleteAutPerfilAcesso($row, $request, $response);
                    }
                    
                    if($row['NRPERFILACESSO']) {
                        $this->insertAutPerfilAcesso($row, $request, $response);
                    }
                }
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function deleteAutGrupOp($row)
    {
        $sql = "DELETE FROM AUTGRUPOP 
                 WHERE IDAUTGRUPOP = :TIPO 
                   AND NRAUTGRUPOP = :NRAUTGRUPOP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'TIPO' => $row['TIPO'],
                'NRAUTGRUPOP' => $row['NRAUTGRUPOP']
            )
        );
    }
    
    private function insertAutGrupOp($row)
    {
        if ($row['CDGRUPOPER'] == ""){
            $this->deleteAutGrupOp($row);
        } else {
            $sql = "INSERT INTO AUTGRUPOP (CDGRUPOPER,
                                           IDAUTGRUPOP,
                                           NRAUTGRUPOP,
                                           NRORG) 
                                   VALUES (:CDGRUPOPER, 
                                           :TIPO, 
                                           :NRAUTGRUPOP, 
                                           :NRORG)";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'CDGRUPOPER'  => $row['CDGRUPOPER'],
                    'TIPO'        => $row['TIPO'],
                    'NRAUTGRUPOP' => $row['NRAUTGRUPOP'],
                    'NRORG'       => $this->environment->getNrorg(),
                )
            );
        }
    }
    
    private function deleteAutPerfilAcesso($row, $request, $response) 
    {
        try {
            $this->dataSourceName = 'autperfilacesso';
            
            $row['__is_new'] = false;
            $requestToSave = new DTO\Request\Row($row, $request->getMethod(),$request->getRoutePath(), $request->getUserId());
            parent::delete($requestToSave, $response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function insertAutPerfilAcesso($row, $request, $response) 
    {
        try {
            $this->dataSourceNameToSave = 'autperfilacesso';
            
            $row['__is_new'] = true;
            $row['NRAUTPERFACESSO'] = $this->newCode->getCodeByTableName("AUTPERFILACESSO", $this->environment->getNrOrg());
            
            $requestToSave = new DTO\Request\Row($row, $request->getMethod(),$request->getRoutePath(), $request->getUserId());
            parent::save($requestToSave, $response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deletePermitPerfAcessAF($request,$response)
    {
        try {
            $row = $request->getRow();
            
            $sql = "SELECT NRAUTPERFACESSO 
                      FROM AUTPERFILACESSO 
                     WHERE NRPERFILACESSO  = :P_NRPERFILACESSO 
                       AND IDAUTPERFACESSO = :P_IDAUTPERFACESSO
                       AND CDFILIAL        = :P_CDFILIAL
                       AND NRORG           = :P_NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'P_NRPERFILACESSO'  => $row['NRPERFILACESSO'],
                    'P_IDAUTPERFACESSO' => $row['IDAUTPERFACESSO'],
                    'P_CDFILIAL'        => $row['CDFILIAL'],
                    'P_NRORG'           => $this->environment->getNrorg()
                )
            );
            
            $dataSet = $stmt->fetchAll();
            
            if (sizeof($dataSet) > 0) {
                $sql = "DELETE FROM AUTPERFILACESSO 
                         WHERE NRAUTPERFACESSO = :P_NRAUTPERFACESSO
                           AND CDFILIAL        = :P_CDFILIAL
                           AND NRORG           = :P_NRORG";
                $stmt = $this->connection->prepare($sql);
                $stmt->execute(
                    array(
                        'P_NRAUTPERFACESSO' => $dataSet[0]['NRAUTPERFACESSO'],
                        'P_CDFILIAL'        => $row['CDFILIAL'],
                        'P_NRORG'           => $this->environment->getNrorg()
                    )
                );
            } else {
                $response->setError(new Error('Não foi possível remover essa permissão. A mesma não foi encontrada em nossa base de dados.', 500));
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deletePermit($request,$response)
    {
        try {
            $this->dataSourceName = "autgrupop";
			$request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
			$dataSet = $request->getDataSet();
			$dataSet->setDataSourceName($this->dataSourceName);
			$this->crudService->delete($response, $dataSet);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function savePermitPerfAcessAF($request, $response) 
    {
        try {
            $row = $request->getRow();
            $sql = "SELECT * 
                      FROM AUTPERFILACESSO 
                     WHERE NRPERFILACESSO  = :P_NRPERFILACESSO 
                       AND IDAUTPERFACESSO = :P_IDAUTPERFACESSO 
                       AND CDFILIAL        = :P_CDFILIAL        
                       AND NRORG           = :P_NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'P_NRPERFILACESSO'  => $row['NRPERFILACESSO'],
                    'P_IDAUTPERFACESSO' => $row['IDAUTPERFACESSO'],
                    'P_CDFILIAL'        => $row['CDFILIAL'],
                    'P_NRORG'           => $this->environment->getNrorg()
                )
            );
            $dataSet = $stmt->fetchAll();

            if(isset($dataSet) && count($dataSet)) {
                $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
            } else {
                $this->dataSourceNameToSave = 'autperfilacesso';
                parent::save($request,$response);
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function savePermitAF($request,$response)
    {
        try {
            $row = $request->getRow();
            $sql = "SELECT * 
                      FROM AUTGRUPOP 
                     WHERE IDAUTGRUPOP = :IDAUTGRUPOP 
                       AND CDGRUPOPER = :CDGRUPOPER";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'IDAUTGRUPOP' => $row['IDAUTGRUPOP'],
                    'CDGRUPOPER'  => $row['CDGRUPOPER']
                    
                )
            );
            $dataSet = $stmt->fetchAll();
            if(sizeof($dataSet) == 0) {
                $this->dataSourceNameToSave = 'autgrupop';
                parent::save($request,$response);
            } else {
                $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deleteAllPermits($request,$response){
        $row = $request->getRow();
        $CDGRUPOPER = $row['CDGRUPOPER'];
        $IDPERMISSAO = $row['IDAUTGRUPOP'];
        $CDFILCENTCMP = $row['CDFILIAL'];
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE CDFILCENTCMP = :CDFILCENTCMP AND CDGRUPOPER = :CDGRUPOPER AND (IDAUTNECECOMP = :IDPERMISSAO OR IDAUTLANCSOLI = :IDPERMISSAO OR IDAUTALTEPRODSOLI = :IDPERMISSAO OR IDAUTALTESOLI = :IDPERMISSAO )";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    // FUNÇÕES DA ABA "FILIAL"
    
    public function saveDiversosFilial (DTO\Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            
            if ($row["IDTIPEMITGER"] == 3) {
                if($this->verificaClientePrincipal($row["CDFILIAL"]) == 0) {
                    $response->setError(new Error('Não há cliente principal cadastrado para a filial informada.', 500));
                }
            }
            
            $row['IDPERALTSAPR'] = $this->concatenaParametroMultiplo($row, 'IDPERALTSAPR', 3);

            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function concatArray($array){
        return is_array($array) ? join('_', $array) : 'T';
    }
    
    private function concatenaParametroMultiplo($row, $nome, $quantidade){
        $resultado = '';
        
        for ($i = 0; $i < $quantidade; $i++) {
            $parametro = $nome . $i;
            
            if (isset($row[$parametro])) {
                $resultado .= $row[$parametro];
            }
        }
        
        return $resultado;
    }
    
    public function replicarParametrizacao(Request\Row $request, Response $response){
        $data = $request->getRow();
        $queryDeleteParams = "DELETE FROM PARCMPSUP
                                WHERE INSTR(:P_CDFILIDEST, CDFILIAL) > 0";
        try
        {
            $params = 
            [
                'P_CDFILIDEST' => self::concatArray($data['NMFILIALDEST'])
            ];
            $this->supUtilities->crud($queryDeleteParams, $params);
            $queryInsertParams = "INSERT INTO 
                                    PARCMPSUP (CDFILIAL, CDEMPRESA, IDTIPEMITGER, IDUTPRODPREF, DSPERIENTFIL, 
                                            IDPECOLISTA, IDENTRSAIDOP, CDTIPOOPER, IDCALPREVCON, IDTPLANCITAF, 
                                            IDUTARCMPFOR, IDPERACRNEC, IDPERCESTNEC, IDSCONESTNEC, IDOBRAFFILRE, 
                                            IDUTLOPERSOL, IDUTAPROVSOL, IDPERLIBAFOU, IDFORMENVMAI, IDPERALTSAPR, 
                                            IDBLALTAFAUT, IDBLBAFDTPRO, IDBLBAFMDPRO, IDTPARQENVMA, DTULTATUPARC, 
                                            IDOBLIBAFMAN, DSOBSUNIDADE, IDIMPINCSOLAPR, IDMAPDISTALMOX, CDGRUPPROD, 
                                            CDSUBGRPROD, NRDIABLQAPROV, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, 
                                            CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO, IDUTLCONFRECAF)
                                    SELECT F.CDFILIAL, P.CDEMPRESA, P.IDTIPEMITGER, P.IDUTPRODPREF, P.DSPERIENTFIL, 
                                            P.IDPECOLISTA, P.IDENTRSAIDOP, P.CDTIPOOPER, P.IDCALPREVCON, P.IDTPLANCITAF, 
                                            P.IDUTARCMPFOR, P.IDPERACRNEC, P.IDPERCESTNEC, P.IDSCONESTNEC, P.IDOBRAFFILRE, 
                                            P.IDUTLOPERSOL, P.IDUTAPROVSOL, P.IDPERLIBAFOU, P.IDFORMENVMAI, P.IDPERALTSAPR, 
                                            P.IDBLALTAFAUT, P.IDBLBAFDTPRO, P.IDBLBAFMDPRO, P.IDTPARQENVMA, P.DTULTATUPARC, 
                                            P.IDOBLIBAFMAN, P.DSOBSUNIDADE, P.IDIMPINCSOLAPR, P.IDMAPDISTALMOX, P.CDGRUPPROD, 
                                            P.CDSUBGRPROD, P.NRDIABLQAPROV, P.NRORG, P.DTINCLUSAO, P.DTULTATU, P.NRORGINCLUSAO, 
                                            P.CDOPERINCLUSAO, P.NRORGULTATU, P.CDOPERULTATU, P.IDATIVO, P.IDUTLCONFRECAF
                                    FROM PARCMPSUP P, FILIAL F
                                        WHERE P.CDFILIAL = :P_CDFILIORIG 
                                             AND INSTR(:P_CDFILIDEST, F.CDFILIAL) > 0";   
            $parametros = 
            [
                'P_CDFILIORIG'   => $data['CDFILIALORIG'],
                'P_CDFILIDEST' => self::concatArray($data['NMFILIALDEST'])
            ];                    
            $this->supUtilities->crud($queryInsertParams, $parametros);
        }
        catch (\Exception $e) 
        {
            throw new \Exception($e->getMessage());
        }
    }
    
    public function verificaClientePrincipal($cdfilial) {
        $sql = "SELECT IDCLIENPRIN FROM CLIENFILIAL WHERE CDFILIAL = :CDFILIAL AND IDCLIENPRIN = 'S'";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $cdfilial
            )
        );
        $dataSet = $stmt->fetchAll();
        return sizeof($dataSet);
    }
    
    public function newFilialParasupri(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parasupri';
            parent::save($request,$response);
         
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function newFilialParcmpsup(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
         
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getCdgrupprodFilial(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $sql = "SELECT
                  CDGRUPPROD
                FROM PARASUPRI
                WHERE CDFILIAL = (SELECT
                    NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) AS CDFILCENTCMP
                  FROM FILIAL FILCENT,
                       FILIAL
                  WHERE FILIAL.CDFILIAL = :CDFILIAL
                  AND NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = FILCENT.CDFILIAL)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $row["CDFILIAL"]
            )
        );
        $dataSet = $stmt->fetchAll();
        if(sizeof($dataSet) == 0) {
            $cdgrupprod = null;
        } else {
            $cdgrupprod = $dataSet[0]["CDGRUPPROD"];
        }
        
        $cdgrupprod = array($cdgrupprod);
        $response->addDataSet(new DataSet ('cdgrupprod', $cdgrupprod));
    }
    
    public function getSubGrupoGeral(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $sql = "SELECT COUNT(*) AS QUANT
                FROM
                    (SELECT F.CDFILIAL
                     FROM FILIAL F
                     WHERE CDFILCENTCMP = :CDFILIAL
                         AND EXISTS
                             (SELECT P.CDGRUPPROD,
                                     P.CDSUBGRPROD
                              FROM PARCMPSUP P
                              WHERE P.CDFILIAL = F.CDFILIAL
                                  AND P.CDSUBGRPROD IS NOT NULL)
                     GROUP BY F.CDFILIAL
                     UNION SELECT F.CDFILIAL
                     FROM FILIAL F
                     WHERE CDFILIAL = :CDFILIAL
                         AND EXISTS
                             (SELECT P.CDGRUPPROD,
                                     P.CDSUBGRPROD
                              FROM PARCMPSUP P
                              WHERE P.CDFILIAL = F.CDFILIAL
                                  AND P.CDSUBGRPROD IS NOT NULL)
                     GROUP BY F.CDFILIAL)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $row["CDFILIAL"]
            )
        );
        $dataSet = $stmt->fetchAll();
        if(sizeof($dataSet) == 0) {
            $quant = 0;
        } else {
            $quant = $dataSet[0]["QUANT"];
        }
        $quant = array($quant);
        $response->addDataSet(new DataSet ('subGrupoGeral', $quant));
    }
    
    public function saveListaPrecoFilial(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function removeAllUnblockPermi($request,$response){
        $row = $request->getRow();
        $IDAUTNECECOMP = $row['IDBLOQALTNEC'];
        $IDBLOQALTSOLAUT = $row['IDBLOQALTSOLAUT'];
        $CDFILCENTCMP = $row['CDFILIAL'];
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE CDFILCENTCMP = :CDFILCENTCMP AND (:P_SOLICMP = 'N' AND ((IDAUTLANCSOLI IS NOT NULL) OR (IDAUTALTEPRODSOLI IS NOT NULL) OR (IDAUTALTESOLI IS NOT NULL)) OR (:P_NECECMP = 'N' AND IDAUTNECECOMP IS NOT NULL))";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'P_SOLICMP'  => $IDBLOQALTSOLAUT,
                'P_NECECMP' => $IDAUTNECECOMP,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    public function insertIdAutNeceCompAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $sql        = "INSERT INTO AUTPERFILACESSOSOLI (NRAUTPERFILACESSOSOLI, 
                                                        NRPERFILACESSO, 
                                                        IDAUTNECECOMP,
                                                        PEALTEQTDESOLI, 
                                                        CDFILCENTCMP, 
                                                        NRORG, 
                                                        IDATIVO, 
                                                        DTINCLUSAO, 
                                                        NRORGINCLUSAO, 
                                                        CDOPERINCLUSAO, 
                                                        NRORGULTATU, 
                                                        CDOPERULTATU)
                                                VALUES (SEQ_AUTPERFILACESSOSOLI.NEXTVAL, 
                                                        :NRPERFILACESSO, 
                                                        :IDPERMISSAO, 
                                                        :PEALTEQTDESOLI, 
                                                        :CDFILCENTCMP, 
                                                        :NRORG, 
                                                        'S', 
                                                        :DTINCLUSAO, 
                                                        :NRORGINCLUSAO, 
                                                        :CDOPERINCLUSAO, 
                                                        :NRORGULTATU, 
                                                        :CDOPERULTATU)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRPERFILACESSO'      => $NRPERFILACESSO,
                'IDPERMISSAO'     => $IDAUTPERFACESSO,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function insertIdAutLancSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $sql        = "INSERT INTO AUTPERFILACESSOSOLI (NRAUTPERFILACESSOSOLI, 
                                                        NRPERFILACESSO, 
                                                        IDAUTLANCSOLI, 
                                                        PEALTEQTDESOLI, 
                                                        CDFILCENTCMP,
                                                        NRORG, 
                                                        IDATIVO, 
                                                        DTINCLUSAO, 
                                                        NRORGINCLUSAO, 
                                                        CDOPERINCLUSAO, 
                                                        NRORGULTATU, 
                                                        CDOPERULTATU) 
                                                VALUES (SEQ_AUTPERFILACESSOSOLI.NEXTVAL, 
                                                        :NRPERFILACESSO, 
                                                        :IDPERMISSAO, 
                                                        :PEALTEQTDESOLI, 
                                                        :CDFILCENTCMP, 
                                                        :NRORG , 
                                                        'S', 
                                                        :DTINCLUSAO, 
                                                        :NRORGINCLUSAO, 
                                                        :CDOPERINCLUSAO, 
                                                        :NRORGULTATU, 
                                                        :CDOPERULTATU)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO'     => $IDAUTPERFACESSO,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function insertIdAutAlteProdSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp){
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $sql        = "INSERT INTO AUTPERFILACESSOSOLI (NRAUTPERFILACESSOSOLI, 
                                                        NRPERFILACESSO, 
                                                        IDAUTALTEPRODSOLI, 
                                                        PEALTEQTDESOLI, 
                                                        CDFILCENTCMP,
                                                        NRORG, 
                                                        IDATIVO, 
                                                        DTINCLUSAO, 
                                                        NRORGINCLUSAO, 
                                                        CDOPERINCLUSAO,
                                                        NRORGULTATU,
                                                        CDOPERULTATU)
                                                VALUES (SEQ_AUTPERFILACESSOSOLI.NEXTVAL,
                                                        :NRPERFILACESSO, 
                                                        :IDPERMISSAO, 
                                                        :PEALTEQTDESOLI, 
                                                        :CDFILCENTCMP, 
                                                        :NRORG, 
                                                        'S', 
                                                        :DTINCLUSAO, 
                                                        :NRORGINCLUSAO, 
                                                        :CDOPERINCLUSAO, 
                                                        :NRORGULTATU, 
                                                        :CDOPERULTATU)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO'     => $IDAUTPERFACESSO,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function insertIdAutAlteSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp){
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $sql        = "INSERT INTO AUTPERFILACESSOSOLI (NRAUTPERFILACESSOSOLI,
                                                        NRPERFILACESSO, 
                                                        IDAUTALTESOLI, 
                                                        PEALTEQTDESOLI, 
                                                        CDFILCENTCMP,
                                                        NRORG, 
                                                        IDATIVO, 
                                                        DTINCLUSAO, 
                                                        NRORGINCLUSAO, 
                                                        CDOPERINCLUSAO, 
                                                        NRORGULTATU, 
                                                        CDOPERULTATU)
                                                VALUES (SEQ_AUTPERFILACESSOSOLI.NEXTVAL, 
                                                        :NRPERFILACESSO, 
                                                        :IDPERMISSAO, 
                                                        :PEALTEQTDESOLI, 
                                                        :CDFILCENTCMP, 
                                                        :NRORG , 
                                                        'S', 
                                                        :DTINCLUSAO, 
                                                        :NRORGINCLUSAO, 
                                                        :CDOPERINCLUSAO, 
                                                        :NRORGULTATU, 
                                                        :CDOPERULTATU)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO'     => $IDAUTPERFACESSO,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function deleteAllPermitsAUTPERFILACESSOSOLI($request,$response){
        $row = $request->getRow();
        $NRPERFILACESSO = $row['NRPERFILACESSO'];
        $IDPERMISSAO = $row['IDAUTPERFACESSO'];
        $CDFILCENTCMP = $row['CDFILIAL'];
        $sql = "DELETE FROM AUTPERFILACESSOSOLI WHERE CDFILCENTCMP = :CDFILCENTCMP AND NRPERFILACESSO = :NRPERFILACESSO AND (IDAUTNECECOMP = :IDPERMISSAO OR IDAUTLANCSOLI = :IDPERMISSAO OR IDAUTALTEPRODSOLI = :IDPERMISSAO OR IDAUTALTESOLI = :IDPERMISSAO )";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    public function savePermitSoli($request, $response)
    {
        try {
            $row = $request->getRow();
            
            $cdGrupoOper       = isset($row['CDGRUPOPER']) ? $row['CDGRUPOPER'] : "";
            $NRPERFILACESSO    = isset($row['NRPERFILACESSO']) ? $row['NRPERFILACESSO'] : $row['CDGRUPOPER'];
            $IDAUTPERFACESSO   = isset($row['IDAUTPERFACESSO'])? $row['IDAUTPERFACESSO'] : $row['IDPERMISSAO'];
            
            $dataSet = [];
            
            //GRUPOPER
            if(!empty($cdGrupoOper) && $row['TPACESSO'] === 'GDO'){
                $sql  = "SELECT *
                           FROM (SELECT AUTGRUPOPSOLI.CDGRUPOPER, AUTGRUPOPSOLI.CDFILCENTCMP, AUTGRUPOPSOLI.PEALTEQTDESOLI, 
                                        NVL(AUTGRUPOPSOLI.IDAUTNECECOMP, NVL(AUTGRUPOPSOLI.IDAUTLANCSOLI, NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI))) IDPERMISSAO 
                                   FROM AUTGRUPOPSOLI
                                  WHERE AUTGRUPOPSOLI.CDFILCENTCMP = :P_CDFILIAL
                                    AND AUTGRUPOPSOLI.CDGRUPOPER = :P_CDGRUPOPER 
                                    AND NVL(AUTGRUPOPSOLI.IDAUTNECECOMP, NVL(AUTGRUPOPSOLI.IDAUTLANCSOLI, NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI))) = :P_IDPERMISSAO 
                                  GROUP BY AUTGRUPOPSOLI.CDGRUPOPER, AUTGRUPOPSOLI.CDFILCENTCMP, AUTGRUPOPSOLI.PEALTEQTDESOLI, 
                                           NVL(AUTGRUPOPSOLI.IDAUTNECECOMP, NVL(AUTGRUPOPSOLI.IDAUTLANCSOLI, NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI)))) PERMISSAO 
                           INNER JOIN GRUPOPER ON PERMISSAO.CDGRUPOPER = GRUPOPER.CDGRUPOPER 
                            LEFT JOIN AUTGRUPOPSOLI NECECOMP ON PERMISSAO.CDGRUPOPER = NECECOMP.CDGRUPOPER 
                                                            AND PERMISSAO.IDPERMISSAO = NECECOMP.IDAUTNECECOMP 
                                                            AND PERMISSAO.CDFILCENTCMP = NECECOMP.CDFILCENTCMP 
                            LEFT JOIN AUTGRUPOPSOLI LANCSOLI ON PERMISSAO.CDGRUPOPER = LANCSOLI.CDGRUPOPER 
                                                            AND PERMISSAO.IDPERMISSAO = LANCSOLI.IDAUTLANCSOLI 
                                                            AND PERMISSAO.CDFILCENTCMP = LANCSOLI.CDFILCENTCMP 
                            LEFT JOIN AUTGRUPOPSOLI ALTEPRODSOLI ON PERMISSAO.CDGRUPOPER = ALTEPRODSOLI.CDGRUPOPER 
                                                                AND PERMISSAO.IDPERMISSAO = ALTEPRODSOLI.IDAUTALTEPRODSOLI 
                                                                AND PERMISSAO.CDFILCENTCMP = ALTEPRODSOLI.CDFILCENTCMP 
                            LEFT JOIN AUTGRUPOPSOLI ALTESOLI ON PERMISSAO.CDGRUPOPER = ALTESOLI.CDGRUPOPER 
                                                            AND PERMISSAO.IDPERMISSAO = ALTESOLI.IDAUTALTESOLI 
                                                            AND PERMISSAO.CDFILCENTCMP = ALTESOLI.CDFILCENTCMP";
                $stmt = $this->connection->prepare($sql);
                $stmt->execute(
                    array(
                        'P_IDPERMISSAO' => $row['IDPERMISSAO'],
                        'P_CDGRUPOPER'  => $cdGrupoOper,
                        'P_CDFILIAL'    => $row['CDFILIAL']
                    )
                );
                $dataSet = $stmt->fetchAll();
                
                if ($row['__is_new']) {
                    try {
                        if (sizeof($dataSet) == 0) {
                            
                            if ($row['IDAUTNECECOMP'] === 'S') {
                                $this->insertIdAutNeceComp($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                            
                            if ($row['IDAUTLANCSOLI'] === 'S') {
                                $this->insertIdAutLancSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                            
                            if ($row['IDAUTALTEPRODSOLI'] === 'S') {
                                $this->insertIdAutAlteProdSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                            
                            if ($row['IDAUTALTESOLI'] === 'S') {
                                $this->insertIdAutAlteSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                        } else {
                            $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
                        }
                    } catch (\Exception $e) {
            		    $response->setError(new Error($e->getMessage(), 500));
                    }
                } else {
                    $rowAntiga = $dataSet[0];
                    if ($rowAntiga['IDAUTNECECOMP'] == 'S' && $row['IDAUTNECECOMP'] === 'N') {
                        $this->deleteIdAutNeceComp($cdGrupoOper, $row['IDPERMISSAO'], $row['CDFILIAL']);
                        
                    } elseif ($rowAntiga['IDAUTNECECOMP'] == 'N' && $row['IDAUTNECECOMP'] === 'S') {
                        $this->insertIdAutNeceComp($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    }
                    
                    if ($rowAntiga['IDAUTLANCSOLI'] == 'S' && $row['IDAUTLANCSOLI'] === 'N') {
                        $this->deleteIdAutLancSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['CDFILIAL']);
                        
                    } elseif ($rowAntiga['IDAUTLANCSOLI'] == 'N' && $row['IDAUTLANCSOLI'] === 'S') {
                        $this->insertIdAutLancSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    }
                    
                    if ($rowAntiga['IDAUTALTEPRODSOLI'] == 'S' && $row['IDAUTALTEPRODSOLI'] === 'N') {
                        $this->deleteIdAutAlteProdSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['CDFILIAL']);
                        
                    } elseif ($rowAntiga['IDAUTALTEPRODSOLI'] == 'N' && $row['IDAUTALTEPRODSOLI'] === 'S') {
                        $this->insertIdAutAlteProdSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    } 
                    
                    if ($rowAntiga['IDAUTALTESOLI'] == 'S' && $row['IDAUTALTESOLI'] === 'N') {
                        $this->deleteIdAutAlteSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['CDFILIAL']);
                    } elseif ($rowAntiga['IDAUTALTESOLI'] == 'N' && $row['IDAUTALTESOLI'] === 'S') {
                        $this->insertIdAutAlteSoli($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    }
                    
                    if ($rowAntiga['PEALTEQTDESOLI'] != $row['PEALTEQTDESOLI']) {
                        $this->updatePEALTEQTDESOLI($cdGrupoOper, $row['IDPERMISSAO'], $row['PEALTEQTDESOLI'], $row['CDFILIAL']);
                    }
                }
            }

            //PERFILACESSO
            if(!empty($NRPERFILACESSO) && $row['TPACESSO'] === 'PDA'){
                $sql = "SELECT AUTPERFILACESSOSOLI.NRPERFILACESSO, PERFILACESSO.NMPERFILACESSO, PERMISSAO.IDAUTGRUPOP, PERMISSAO.PEALTEQTDESOLI, 
                               CASE NVL(NECECOMP.IDAUTNECECOMP, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTNECECOMP, 
                               CASE NVL(LANCSOLI.IDAUTLANCSOLI, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTLANCSOLI, 
                               CASE NVL(ALTEPRODSOLI.IDAUTALTEPRODSOLI, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTALTEPRODSOLI, 
                               CASE NVL(ALTESOLI.IDAUTALTESOLI, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTALTESOLI, 
                               AUTPERFILACESSOSOLI.NRORG 
                          FROM (SELECT AUTPERFILACESSOSOLI.NRPERFILACESSO, AUTPERFILACESSOSOLI.CDFILCENTCMP, AUTPERFILACESSOSOLI.PEALTEQTDESOLI, 
                                       NVL(AUTPERFILACESSOSOLI.IDAUTNECECOMP, NVL(AUTPERFILACESSOSOLI.IDAUTLANCSOLI, NVL(AUTPERFILACESSOSOLI.IDAUTALTEPRODSOLI, AUTPERFILACESSOSOLI.IDAUTALTESOLI))) IDAUTGRUPOP 
                                  FROM AUTPERFILACESSOSOLI
                                 WHERE AUTPERFILACESSOSOLI.CDFILCENTCMP = :P_CDFILIAL 
                                   AND AUTPERFILACESSOSOLI.NRPERFILACESSO = :P_NRPERFILACESSO 
                                   AND NVL(AUTPERFILACESSOSOLI.IDAUTNECECOMP, NVL(AUTPERFILACESSOSOLI.IDAUTLANCSOLI, NVL(AUTPERFILACESSOSOLI.IDAUTALTEPRODSOLI, AUTPERFILACESSOSOLI.IDAUTALTESOLI))) = :P_IDPERMISSAO 
                                 GROUP BY AUTPERFILACESSOSOLI.NRPERFILACESSO, AUTPERFILACESSOSOLI.CDFILCENTCMP, AUTPERFILACESSOSOLI.PEALTEQTDESOLI, 
                                       NVL(AUTPERFILACESSOSOLI.IDAUTNECECOMP, NVL(AUTPERFILACESSOSOLI.IDAUTLANCSOLI, NVL(AUTPERFILACESSOSOLI.IDAUTALTEPRODSOLI, AUTPERFILACESSOSOLI.IDAUTALTESOLI)))) PERMISSAO 
                          INNER JOIN AUTPERFILACESSOSOLI ON PERMISSAO.NRPERFILACESSO = AUTPERFILACESSOSOLI.NRPERFILACESSO 
                          INNER JOIN PERFILACESSO ON AUTPERFILACESSOSOLI.NRPERFILACESSO = PERFILACESSO.NRPERFILACESSO
                           LEFT JOIN AUTPERFILACESSOSOLI NECECOMP ON PERMISSAO.NRPERFILACESSO = NECECOMP.NRPERFILACESSO 
                                                                 AND PERMISSAO.IDAUTGRUPOP = NECECOMP.IDAUTNECECOMP 
                                                                 AND PERMISSAO.CDFILCENTCMP = NECECOMP.CDFILCENTCMP 
                           LEFT JOIN AUTPERFILACESSOSOLI LANCSOLI ON PERMISSAO.NRPERFILACESSO = LANCSOLI.NRPERFILACESSO 
                                                                 AND PERMISSAO.IDAUTGRUPOP = LANCSOLI.IDAUTLANCSOLI 
                                                                 AND PERMISSAO.CDFILCENTCMP = LANCSOLI.CDFILCENTCMP 
                           LEFT JOIN AUTPERFILACESSOSOLI ALTEPRODSOLI ON PERMISSAO.NRPERFILACESSO = ALTEPRODSOLI.NRPERFILACESSO 
                                                                     AND PERMISSAO.IDAUTGRUPOP = ALTEPRODSOLI.IDAUTALTEPRODSOLI 
                                                                     AND PERMISSAO.CDFILCENTCMP = ALTEPRODSOLI.CDFILCENTCMP 
                           LEFT JOIN AUTPERFILACESSOSOLI ALTESOLI ON PERMISSAO.NRPERFILACESSO = ALTESOLI.NRPERFILACESSO 
                                                                 AND PERMISSAO.IDAUTGRUPOP = ALTESOLI.IDAUTALTESOLI 
                                                                 AND PERMISSAO.CDFILCENTCMP = ALTESOLI.CDFILCENTCMP";
                $stmt = $this->connection->prepare($sql);
                $stmt->execute(
                    array(
                        'P_IDPERMISSAO' => $IDAUTPERFACESSO,
                        'P_NRPERFILACESSO'  => $NRPERFILACESSO,
                        'P_CDFILIAL'  => $row['CDFILIAL']
                    )
                );
                $dataSet = $stmt->fetchAll();
                
                if ($row['__is_new']) {
                    try {
                        if (sizeof($dataSet) == 0) {
                            
                            if ($row['IDAUTNECECOMP'] === 'S') {
                                $this->insertIdAutNeceCompAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                            
                            if ($row['IDAUTLANCSOLI'] === 'S') {
                                $this->insertIdAutLancSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                            
                            if ($row['IDAUTALTEPRODSOLI'] === 'S') {
                                $this->insertIdAutAlteProdSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                            
                            if ($row['IDAUTALTESOLI'] === 'S') {
                                $this->insertIdAutAlteSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                            }
                            
                        } else {
                            $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
                        }
                    } catch (\Exception $e) {
            		    $response->setError(new Error($e->getMessage(), 500));
                    }
                } else {
                    $rowAntiga = $dataSet[0];
                    if ($rowAntiga['IDAUTNECECOMP'] == 'S' && $row['IDAUTNECECOMP'] === 'N') {
                        $this->deleteIdAutNeceCompAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['CDFILIAL']);
                        
                    } elseif ($rowAntiga['IDAUTNECECOMP'] == 'N' && $row['IDAUTNECECOMP'] === 'S') {
                        $this->insertIdAutNeceCompAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    }
                    
                    if ($rowAntiga['IDAUTLANCSOLI'] == 'S' && $row['IDAUTLANCSOLI'] === 'N') {
                        $this->deleteIdAutLancSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['CDFILIAL']);
                        
                    } elseif ($rowAntiga['IDAUTLANCSOLI'] == 'N' && $row['IDAUTLANCSOLI'] === 'S') {
                        $this->insertIdAutLancSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    }
                    
                    if ($rowAntiga['IDAUTALTEPRODSOLI'] == 'S' && $row['IDAUTALTEPRODSOLI'] === 'N') {
                        $this->deleteIdAutAlteProdSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['CDFILIAL']);
                        
                    } elseif ($rowAntiga['IDAUTALTEPRODSOLI'] == 'N' && $row['IDAUTALTEPRODSOLI'] === 'S') {
                        $this->insertIdAutAlteProdSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    } 
                    
                    if ($rowAntiga['IDAUTALTESOLI'] == 'S' && $row['IDAUTALTESOLI'] === 'N') {
                        $this->deleteIdAutAlteSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['CDFILIAL']);
                    } elseif ($rowAntiga['IDAUTALTESOLI'] == 'N' && $row['IDAUTALTESOLI'] === 'S') {
                        $this->insertIdAutAlteSoliAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['DTINCLUSAO'], $row['CDFILIAL']);
                    }
                    
                    if ($rowAntiga['PEALTEQTDESOLI'] != $row['PEALTEQTDESOLI']) {
                        $this->updatePEALTEQTDESOLIAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $row['PEALTEQTDESOLI'], $row['CDFILIAL']);
                    }
                }
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function insertIdAutNeceComp($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTNECECOMP, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG, 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    private function insertIdAutLancSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTLANCSOLI, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG , 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    private function insertIdAutAlteProdSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTALTEPRODSOLI, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG, 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    private function insertIdAutAlteSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTALTESOLI, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG , 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    private function deleteIdAutNeceComp($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTNECECOMP = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function deleteIdAutLancSoli($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTLANCSOLI = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function deleteIdAutAlteProdSoli($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTALTEPRODSOLI = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function deleteIdAutAlteSoli($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTALTESOLI = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function updatePEALTEQTDESOLI($CDGRUPOPER, $IDPERMISSAO, $PEALTEQTDESOLI,$CDFILCENTCMP)
    {
        $sql = "UPDATE AUTGRUPOPSOLI SET PEALTEQTDESOLI = :PEALTEQTDESOLI WHERE CDGRUPOPER = :CDGRUPOPER AND (IDAUTNECECOMP = :IDPERMISSAO OR IDAUTLANCSOLI = :IDPERMISSAO OR IDAUTALTEPRODSOLI = :IDPERMISSAO OR IDAUTALTESOLI = :IDPERMISSAO ) AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'PEALTEQTDESOLI' => $PEALTEQTDESOLI,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
        
    }
    
    private function deleteIdAutNeceCompAUTPERFILACESSOSOLI($NRPERFILACESSO,$IDAUTPERFACESSO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTPERFILACESSOSOLI WHERE IDAUTNECECOMP = :IDPERMISSAO AND NRPERFILACESSO = :NRPERFILACESSO AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO' => $IDAUTPERFACESSO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function deleteIdAutLancSoliAUTPERFILACESSOSOLI($NRPERFILACESSO,$IDAUTPERFACESSO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTPERFILACESSOSOLI WHERE IDAUTLANCSOLI = :IDPERMISSAO AND NRPERFILACESSO = :NRPERFILACESSO AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO' => $IDAUTPERFACESSO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function deleteIdAutAlteProdSoliAUTPERFILACESSOSOLI($NRPERFILACESSO,$IDAUTPERFACESSO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTPERFILACESSOSOLI WHERE IDAUTALTEPRODSOLI = :IDPERMISSAO AND NRPERFILACESSO = :NRPERFILACESSO AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO' => $IDAUTPERFACESSO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function deleteIdAutAlteSoliAUTPERFILACESSOSOLI($NRPERFILACESSO,$IDAUTPERFACESSO,$CDFILCENTCMP)
    {
        $sql = "DELETE FROM AUTPERFILACESSOSOLI WHERE IDAUTALTESOLI = :IDPERMISSAO AND NRPERFILACESSO = :NRPERFILACESSO AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO' => $IDAUTPERFACESSO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    private function updatePEALTEQTDESOLIAUTPERFILACESSOSOLI($NRPERFILACESSO, $IDAUTPERFACESSO, $PEALTEQTDESOLI,$CDFILCENTCMP)
    {
        $sql = "UPDATE AUTPERFILACESSOSOLI SET PEALTEQTDESOLI = :PEALTEQTDESOLI WHERE NRPERFILACESSO = :NRPERFILACESSO AND (IDAUTNECECOMP = :IDPERMISSAO OR IDAUTLANCSOLI = :IDPERMISSAO OR IDAUTALTEPRODSOLI = :IDPERMISSAO OR IDAUTALTESOLI = :IDPERMISSAO ) AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRPERFILACESSO'  => $NRPERFILACESSO,
                'IDPERMISSAO' => $IDAUTPERFACESSO,
                'PEALTEQTDESOLI' => $PEALTEQTDESOLI,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
        
    }
}