/* Sistemas Integrados TECNISA

Nome: 8987_SUPTRGS_LOG_SUP_PEDIDOEXOL.SQL

Descrio:
   Trigger para gravar o registro de alteraes na tabela PEDIDOEXOL.

Criao:
   18/08/2008 - Davidson Henrique Gontijo
*/
/* Tabela PEDIDOEXOL: Lanamento de Pedidos do OL */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela PEDIDOEXOL */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela Lanamento de Pedidos do OL,
             utilizando a tabela Geral de Logs de Operaes */


IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_SUP_PEDIDOEXOL' AND
                 TYPE = 'TR' 		       AND
	              U.UID = O.UID            AND
	              U.NAME = USER)
DROP TRIGGER LOG_SUP_PEDIDOEXOL
GO                   


CREATE  TRIGGER LOG_SUP_PEDIDOEXOL
ON PEDIDOEXOL
FOR INSERT, UPDATE, DELETE
AS
   DECLARE  @V_USUARIO   VARCHAR(40);
   DECLARE  @V_TIPO      VARCHAR(1);
   DECLARE  @V_ITPESQ    VARCHAR(80);
   DECLARE  @V_DESC      VARCHAR(1500);
   DECLARE  @V_DTOPER    DATETIME;

   /*VARIVEIS DO CURSOR C_CURSOR*/

   DECLARE @V_ID_COMANDO            VARCHAR(1) ;

   DECLARE @V_OLD_CDFILDEST         VARCHAR(4);
   DECLARE @V_OLD_CDFILLANC         VARCHAR(4);
   DECLARE @V_OLD_NRPEDEXOL         VARCHAR(10);
   DECLARE @V_OLD_DTPEDEXOL         VARCHAR(20);
   DECLARE @V_OLD_IDBAIXEXOL        VARCHAR(2);
   DECLARE @V_OLD_IDBAIXEXSAI       VARCHAR(2);
   DECLARE @V_OLD_IDEMITEXOL        VARCHAR(2);
   DECLARE @V_OLD_IDTPFRETEXOL      VARCHAR(2);
   DECLARE @V_OLD_IDTPJTREXOL       VARCHAR(2);
   DECLARE @V_OLD_NRINSJTREXOL      VARCHAR(20);
   DECLARE @V_OLD_CDEMPRESA         VARCHAR(2);
   DECLARE @V_OLD_CDTIPCOB          VARCHAR(2);
   DECLARE @V_OLD_CDTPCTPAGAR       VARCHAR(6);
   DECLARE @V_OLD_CDFILIOPELOG      VARCHAR(4);
   DECLARE @V_OLD_IDTIPOEXOL        VARCHAR(1);

   DECLARE @V_NEW_CDFILDEST         VARCHAR(4);
   DECLARE @V_NEW_CDFILLANC         VARCHAR(4);
   DECLARE @V_NEW_NRPEDEXOL         VARCHAR(10);
   DECLARE @V_NEW_DTPEDEXOL         VARCHAR(20);
   DECLARE @V_NEW_IDBAIXEXOL        VARCHAR(2);
   DECLARE @V_NEW_IDBAIXEXSAI       VARCHAR(2);
   DECLARE @V_NEW_IDEMITEXOL        VARCHAR(2);
   DECLARE @V_NEW_IDTPFRETEXOL      VARCHAR(2);
   DECLARE @V_NEW_IDTPJTREXOL       VARCHAR(2);
   DECLARE @V_NEW_NRINSJTREXOL      VARCHAR(20);
   DECLARE @V_NEW_CDEMPRESA         VARCHAR(2);
   DECLARE @V_NEW_CDTIPCOB          VARCHAR(2);
   DECLARE @V_NEW_CDTPCTPAGAR       VARCHAR(6);
   DECLARE @V_NEW_CDFILIOPELOG      VARCHAR(4);
   DECLARE @V_NEW_IDTIPOEXOL        VARCHAR(1);

BEGIN

   SET @V_DESC     = '';
   SET @V_TIPO     = '0';

   EXEC NMUSUARIO @V_USUARIO;
   SET @V_USUARIO = ISNULL(@V_USUARIO, ' ');

   DECLARE C_CURSOR CURSOR FOR
      SELECT
             'D' IDCOMANDO,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             DELETED.CDFILDEST,
             DELETED.CDFILLANC,
             DELETED.NRPEDEXOL,
             CONVERT(VARCHAR, DELETED.DTPEDEXOL),
             DELETED.IDBAIXEXOL,
             DELETED.IDBAIXEXSAI,
             DELETED.IDEMITEXOL,
             DELETED.IDTPFRETEXOL,
             DELETED.IDTPJTREXOL,
             DELETED.NRINSJTREXOL,
             DELETED.CDEMPRESA,
             DELETED.CDTIPCOB,
             DELETED.CDTPCTPAGAR,
             DELETED.CDFILIOPELOG,
             DELETED.IDTIPOEXOL
      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)

      UNION ALL

      SELECT
            'U' IDCOMANDO,
            INSERTED.CDFILDEST,
            INSERTED.CDFILLANC,
            INSERTED.NRPEDEXOL,
            CONVERT(VARCHAR, INSERTED.DTPEDEXOL),
            INSERTED.IDBAIXEXOL,
            INSERTED.IDBAIXEXSAI,
            INSERTED.IDEMITEXOL,
            INSERTED.IDTPFRETEXOL,
            INSERTED.IDTPJTREXOL,
            INSERTED.NRINSJTREXOL,
            INSERTED.CDEMPRESA,
            INSERTED.CDTIPCOB,
            INSERTED.CDTPCTPAGAR,
            INSERTED.CDFILIOPELOG,
            INSERTED.IDTIPOEXOL,

            DELETED.CDFILDEST,
            DELETED.CDFILLANC,
            DELETED.NRPEDEXOL,
            CONVERT(VARCHAR, DELETED.DTPEDEXOL),
            DELETED.IDBAIXEXOL,
            DELETED.IDBAIXEXSAI,
            DELETED.IDEMITEXOL,
            DELETED.IDTPFRETEXOL,
            DELETED.IDTPJTREXOL,
            DELETED.NRINSJTREXOL,
            DELETED.CDEMPRESA,
            DELETED.CDTIPCOB,
            DELETED.CDTPCTPAGAR,
            DELETED.CDFILIOPELOG,
            DELETED.IDTIPOEXOL
      FROM
             INSERTED,
             DELETED
      WHERE
             INSERTED.CDFILDEST =  DELETED.CDFILDEST     AND
             INSERTED.CDFILLANC =  DELETED.CDFILLANC     AND
             INSERTED.NRPEDEXOL =  DELETED.NRPEDEXOL


      UNION ALL
      SELECT
             'I' IDCOMANDO,
             INSERTED.CDFILDEST,
             INSERTED.CDFILLANC,
             INSERTED.NRPEDEXOL,
             CONVERT(VARCHAR, INSERTED.DTPEDEXOL),
             INSERTED.IDBAIXEXOL,
             INSERTED.IDBAIXEXSAI,
             INSERTED.IDEMITEXOL,
             INSERTED.IDTPFRETEXOL,
             INSERTED.IDTPJTREXOL,
             INSERTED.NRINSJTREXOL,
             INSERTED.CDEMPRESA,
             INSERTED.CDTIPCOB,
             INSERTED.CDTPCTPAGAR,
             INSERTED.CDFILIOPELOG,
             INSERTED.IDTIPOEXOL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL,
             NULL
      FROM
         INSERTED
      WHERE
         0 = (SELECT COUNT(*) FROM DELETED)

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                 @V_NEW_CDFILDEST,
                                 @V_NEW_CDFILLANC,
                                 @V_NEW_NRPEDEXOL,
                                 @V_NEW_DTPEDEXOL,
                                 @V_NEW_IDBAIXEXOL,
                                 @V_NEW_IDBAIXEXSAI,
                                 @V_NEW_IDEMITEXOL,
                                 @V_NEW_IDTPFRETEXOL,
                                 @V_NEW_IDTPJTREXOL,
                                 @V_NEW_NRINSJTREXOL,
                                 @V_NEW_CDEMPRESA,
                                 @V_NEW_CDTIPCOB,
                                 @V_NEW_CDTPCTPAGAR,
                                 @V_NEW_CDFILIOPELOG,
                                 @V_NEW_IDTIPOEXOL,

                                 @V_OLD_CDFILDEST,
                                 @V_OLD_CDFILLANC,
                                 @V_OLD_NRPEDEXOL,
                                 @V_OLD_DTPEDEXOL,
                                 @V_OLD_IDBAIXEXOL,
                                 @V_OLD_IDBAIXEXSAI,
                                 @V_OLD_IDEMITEXOL,
                                 @V_OLD_IDTPFRETEXOL,
                                 @V_OLD_IDTPJTREXOL,
                                 @V_OLD_NRINSJTREXOL,
                                 @V_OLD_CDEMPRESA,
                                 @V_OLD_CDTIPCOB,
                                 @V_OLD_CDTPCTPAGAR,
                                 @V_OLD_CDFILIOPELOG,
                                 @V_OLD_IDTIPOEXOL;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF @V_ID_COMANDO= 'D' /*DELETING*/ BEGIN
         IF @V_OLD_CDFILDEST IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Filial Dest.'  + @V_OLD_CDFILDEST + ' ';
         END;
         IF @V_OLD_CDFILLANC IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Filial Lan.' + @V_OLD_CDFILLANC + ' ';
         END;
         IF @V_OLD_NRPEDEXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Pedido' + @V_OLD_NRPEDEXOL + ' ';
         END;
         IF @V_OLD_DTPEDEXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Dt. Oper.' + @V_OLD_DTPEDEXOL + ' ';
         END;
         IF @V_OLD_IDBAIXEXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'ID Baixa'  + @V_OLD_IDBAIXEXOL + ' ';
         END;
         IF @V_OLD_IDBAIXEXSAI IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'ID Sada'  + @V_OLD_IDBAIXEXSAI + ' ';
         END;
         IF @V_OLD_IDEMITEXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'ID Emitente(NF Dest.)' + @V_OLD_IDEMITEXOL + ' ';
         END;
         IF @V_OLD_IDTPFRETEXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'ID Frete'  + @V_OLD_IDTPFRETEXOL + ' ';
         END;
         IF @V_OLD_IDTPJTREXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'ID Insc. Jur. Trans.'  + @V_OLD_IDTPJTREXOL + ' ';
         END;
         IF @V_OLD_NRINSJTREXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Insc. Jur. Trans.' + @V_OLD_NRINSJTREXOL + ' ';
         END;
         IF @V_OLD_CDEMPRESA IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Empresa' + @V_OLD_CDEMPRESA + ' ';
         END;
         IF @V_OLD_CDTIPCOB IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Tipo Cobr.' + @V_OLD_CDTIPCOB + ' ';
         END;
         IF @V_OLD_CDTPCTPAGAR IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Conta a PG.' + @V_OLD_CDTPCTPAGAR + ' ';
         END;
         IF @V_OLD_CDFILIOPELOG IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Filial de Oper.' + @V_OLD_CDFILIOPELOG + ' ';
         END;
         IF @V_OLD_IDTIPOEXOL IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'ID Pedido' + @V_OLD_IDTIPOEXOL + ' ';
         END;

         SET @V_TIPO = '3';
         SET @V_ITPESQ = @V_OLD_CDFILDEST + @V_OLD_CDFILLANC + @V_OLD_NRPEDEXOL;
      END
      ELSE BEGIN
         IF @V_ID_COMANDO= 'U' /*UPDATING*/ BEGIN
            IF (ISNULL(@V_OLD_CDFILDEST, '')      <>       ISNULL(@V_NEW_CDFILDEST,''))    OR
               (ISNULL(@V_OLD_CDFILLANC, '')      <>       ISNULL(@V_NEW_CDFILLANC,''))    OR
               (ISNULL(@V_OLD_NRPEDEXOL, '')      <>       ISNULL(@V_NEW_NRPEDEXOL,''))    OR
               (ISNULL(@V_OLD_DTPEDEXOL, '')      <>       ISNULL(@V_NEW_DTPEDEXOL,''))    OR
               (ISNULL(@V_OLD_IDBAIXEXOL, '')     <>       ISNULL(@V_NEW_IDBAIXEXOL,''))   OR
               (ISNULL(@V_OLD_IDBAIXEXSAI, '')    <>       ISNULL(@V_NEW_IDBAIXEXSAI,''))  OR
               (ISNULL(@V_OLD_IDEMITEXOL, '')     <>       ISNULL(@V_NEW_IDEMITEXOL,''))   OR
               (ISNULL(@V_OLD_IDTPFRETEXOL, '')   <>       ISNULL(@V_NEW_IDTPFRETEXOL,'')) OR
               (ISNULL(@V_OLD_IDTPJTREXOL, '')    <>       ISNULL(@V_NEW_IDTPJTREXOL,''))  OR
               (ISNULL(@V_OLD_NRINSJTREXOL, '')   <>       ISNULL(@V_NEW_NRINSJTREXOL,'')) OR
               (ISNULL(@V_OLD_CDEMPRESA, '')      <>       ISNULL(@V_NEW_CDEMPRESA,''))    OR
               (ISNULL(@V_OLD_CDTIPCOB, '')       <>       ISNULL(@V_NEW_CDTIPCOB,''))     OR
               (ISNULL(@V_OLD_CDTPCTPAGAR, '')    <>       ISNULL(@V_NEW_CDTPCTPAGAR,''))  OR
               (ISNULL(@V_OLD_CDFILIOPELOG, '')   <>       ISNULL(@V_NEW_CDFILIOPELOG,'')) OR
               (ISNULL(@V_OLD_IDTIPOEXOL, '')     <>       ISNULL(@V_NEW_IDTIPOEXOL,''))   BEGIN

               IF ISNULL(@V_OLD_CDFILDEST, '') <> ISNULL(@V_NEW_CDFILDEST, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Filial Dest.'  + @V_NEW_CDFILDEST + ' ';
               END;
               IF ISNULL(@V_OLD_CDFILLANC, '') <> ISNULL(@V_NEW_CDFILLANC, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Filial Lan.'  + @V_NEW_CDFILLANC + ' ';
               END;
               IF ISNULL(@V_OLD_NRPEDEXOL, '') <> ISNULL(@V_NEW_NRPEDEXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Tipo de Pedido' + @V_NEW_NRPEDEXOL + ' ';
               END;
               IF ISNULL(@V_OLD_DTPEDEXOL, '') <> ISNULL(@V_NEW_DTPEDEXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'DT Oper.' + @V_NEW_DTPEDEXOL + ' ';
               END;
               IF ISNULL(@V_OLD_IDBAIXEXOL, '') <> ISNULL(@V_NEW_IDBAIXEXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'ID Baixa' + @V_NEW_IDBAIXEXOL + ' ';
               END;
               IF ISNULL(@V_OLD_IDBAIXEXSAI, '') <> ISNULL(@V_NEW_IDBAIXEXSAI, '') BEGIN
                  SET @V_DESC = @V_DESC + 'ID Sada' + @V_NEW_IDBAIXEXSAI + ' ';
               END;
               IF ISNULL(@V_OLD_IDEMITEXOL, '') <> ISNULL(@V_NEW_IDEMITEXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'ID Emitente(NF Dest.)' + @V_NEW_IDEMITEXOL + ' ';
               END;
               IF ISNULL(@V_OLD_IDTPFRETEXOL, '') <> ISNULL(@V_NEW_IDTPFRETEXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'ID Frete'  + @V_NEW_IDTPFRETEXOL + ' ';
               END;
               IF ISNULL(@V_OLD_IDTPJTREXOL, '') <> ISNULL(@V_NEW_IDTPJTREXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'ID Insc. Jur. Trans.' + @V_NEW_IDTPJTREXOL + ' ';
               END;
               IF ISNULL(@V_OLD_NRINSJTREXOL, '') <> ISNULL(@V_NEW_NRINSJTREXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Insc. Jur. Trans.'  + @V_NEW_NRINSJTREXOL + ' ';
               END;
               IF ISNULL(@V_OLD_CDEMPRESA, '') <> ISNULL(@V_NEW_CDEMPRESA, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Empresa.' + @V_NEW_CDEMPRESA + ' ';
               END;
               IF ISNULL(@V_OLD_CDTIPCOB, '') <> ISNULL(@V_NEW_CDTIPCOB, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Tipo de Cobr.' + @V_NEW_CDTIPCOB + ' ';
               END;
               IF ISNULL(@V_OLD_CDTPCTPAGAR, '') <> ISNULL(@V_NEW_CDTPCTPAGAR, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Conta a PG.'  + @V_NEW_CDTPCTPAGAR + ' ';
               END;
               IF ISNULL(@V_OLD_CDFILIOPELOG, '') <> ISNULL(@V_NEW_CDFILIOPELOG, '') BEGIN
                  SET @V_DESC = @V_DESC + 'Filial de Oper.' + @V_NEW_CDFILIOPELOG + ' ';
               END;
               IF ISNULL(@V_OLD_IDTIPOEXOL, '') <> ISNULL(@V_NEW_IDTIPOEXOL, '') BEGIN
                  SET @V_DESC = @V_DESC + 'ID Pedido' + @V_NEW_IDTIPOEXOL;
               END;

               SET @V_TIPO   = '2';
               SET @V_ITPESQ = @V_NEW_CDFILDEST + @V_NEW_CDFILLANC + @V_NEW_NRPEDEXOL;
            END;
         END
         ELSE BEGIN
            IF @V_NEW_CDFILDEST IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Filial Dest.'  + @V_NEW_CDFILDEST + ' ';
            END;
            IF @V_NEW_CDFILLANC IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Filial Lan.'  + @V_NEW_CDFILLANC + ' ';
            END;
            IF @V_NEW_NRPEDEXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Tipo de Pedido' + @V_NEW_NRPEDEXOL + ' ';
            END;
            IF @V_NEW_DTPEDEXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'DT Oper.' + @V_NEW_DTPEDEXOL + ' ';
            END;
            IF @V_NEW_IDBAIXEXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'ID Baixa' + @V_NEW_IDBAIXEXOL + ' ';
            END;
            IF @V_NEW_IDBAIXEXSAI IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'ID Sada' + @V_NEW_IDBAIXEXSAI + ' ';
            END;
            IF @V_NEW_IDEMITEXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'ID Emitente(NF Dest.)' + @V_NEW_IDEMITEXOL + ' ';
            END;
            IF @V_NEW_IDTPFRETEXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'ID Frete'  + @V_NEW_IDTPFRETEXOL + ' ';
            END;
            IF @V_NEW_IDTPJTREXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'ID Insc. Jur. Trans.' + @V_NEW_IDTPJTREXOL + ' ';
            END;
            IF @V_NEW_NRINSJTREXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Insc. Jur. Trans.'  + @V_NEW_NRINSJTREXOL + ' ';
             END;
            IF @V_NEW_CDEMPRESA IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Empresa' + @V_NEW_CDEMPRESA + ' ';
            END;
            IF @V_NEW_CDTIPCOB IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Tipo de Cobr.' + @V_NEW_CDTIPCOB + ' ';
            END;
            IF @V_NEW_CDTPCTPAGAR IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Conta a PG.'  + @V_NEW_CDTPCTPAGAR + ' ';
            END;
            IF @V_NEW_CDFILIOPELOG IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Filial de Oper.' + @V_NEW_CDFILIOPELOG + ' ';
            END;
            IF @V_NEW_IDTIPOEXOL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'ID Pedido' + @V_NEW_IDTIPOEXOL;
            END;

            SET  @V_TIPO   = '1';
            SET @V_ITPESQ = @V_NEW_CDFILDEST + @V_NEW_CDFILLANC + @V_NEW_NRPEDEXOL;
         END;
      END;
      EXEC NMUSUARIO @V_USUARIO;

      SET @V_USUARIO = ISNULL(@V_USUARIO, ' ');

      IF (@V_TIPO <> '0')  BEGIN
         IF @V_DESC IS NOT NULL BEGIN
            IF @V_USUARIO IS NOT NULL BEGIN
               SET  @V_DTOPER = GETDATE();
               SET  @V_DESC = SUBSTRING(@V_DESC, 1, 300);
                  INSERT INTO LOGOPERA
                             (NMTABELA, DTOPERACAO, NMRESPOPER,
                              IDTIPOOPER, CDPESQITEM, DSOPERACAO, CDFILLOGOPER)
                         VALUES
                             ('PEDIDOEXOL', @V_DTOPER, @V_USUARIO,
                              @V_TIPO, @V_ITPESQ, @V_DESC, @V_NEW_CDFILLANC);
            END;
         END;
      END;
      FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                    @V_NEW_CDFILDEST,
                                    @V_NEW_CDFILLANC,
                                    @V_NEW_NRPEDEXOL,
                                    @V_NEW_DTPEDEXOL,
                                    @V_NEW_IDBAIXEXOL,
                                    @V_NEW_IDBAIXEXSAI,
                                    @V_NEW_IDEMITEXOL,
                                    @V_NEW_IDTPFRETEXOL,
                                    @V_NEW_IDTPJTREXOL,
                                    @V_NEW_NRINSJTREXOL,
                                    @V_NEW_CDEMPRESA,
                                    @V_NEW_CDTIPCOB,
                                    @V_NEW_CDTPCTPAGAR,
                                    @V_NEW_CDFILIOPELOG,
                                    @V_NEW_IDTIPOEXOL,
                                    @V_OLD_CDFILDEST,
                                    @V_OLD_CDFILLANC,
                                    @V_OLD_NRPEDEXOL,
                                    @V_OLD_DTPEDEXOL,
                                    @V_OLD_IDBAIXEXOL,
                                    @V_OLD_IDBAIXEXSAI,
                                    @V_OLD_IDEMITEXOL,
                                    @V_OLD_IDTPFRETEXOL,
                                    @V_OLD_IDTPJTREXOL,
                                    @V_OLD_NRINSJTREXOL,
                                    @V_OLD_CDEMPRESA,
                                    @V_OLD_CDTIPCOB,
                                    @V_OLD_CDTPCTPAGAR,
                                    @V_OLD_CDFILIOPELOG,
                                    @V_OLD_IDTIPOEXOL;
   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_SUP_PEDIDOEXOL','5.05.002';
GO

